@@ -154,7 +154,7 @@ class SimpleInvoice(BaseInvoice):
         self.pdf.drawString(LEFT * mm, TOP * mm, _(u'Customer'))
         self.pdf.setFont('DejaVu', 8)
 
-        text = self.pdf.beginText((LEFT + 2) * mm, (TOP - 4) * mm)
+        text = self.pdf.beginText((LEFT + 2) * mm, (TOP - 6) * mm)
         text.textLines(self.invoice.client.get_address_lines())
         self.pdf.drawText(text)
 
@@ -202,8 +202,10 @@ class SimpleInvoice(BaseInvoice):
         lines = [
             self.invoice.provider.bank_name,
             '%s: %s' % (_(u'Account n.'), self.invoice.provider.bank_account),
-            '%s: %s' % (_(u'Variable symbol'), self.invoice.variable_symbol)
         ]
+        if self.invoice.variable_symbol:
+            lines.append(
+                '%s: %s' % (_(u'Variable symbol'), self.invoice.variable_symbol))
         if self.invoice.specific_symbol:
             lines.append(
                 '%s: %s' % (_(u'Specific symbol'), self.invoice.specific_symbol))
